#
# spec file for package vale
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           vale
Version:        2.23.0
Release:        bp155.1.7
Summary:        CLI tool to lint prose text with syntax awareneness and extensible markup format support
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/errata-ai/vale
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.18

%description
Vale is a command-line tool that brings code-like linting to prose. It's fast,
cross-platform (Windows, macOS, and Linux), and highly customizable.

Vale has support for markup: Vale has a rich understanding of many markup
formats, allowing it to avoid syntax-related false positives and intelligently
exclude code snippets from prose-related rules.

Vale includes a highly customizable extension system capable of enforcing your
style-be it a standard editorial style guide or a custom in-house set of rules
(such as those created by GitLab, Homebrew, Linode, CockroachDB, and Spotify).

https://vale.sh/

%prep
%autosetup -a 1

%build
# Build the binary.
go build \
   -mod=vendor \
   -tags extended \
   -buildmode=pie \
   ./cmd/vale

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"
# Install empty styles directory for use by other packages
install --directory %{buildroot}%{_datarootdir}/%{name}/styles

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
# Package empty styles directory for use by other packages
%dir %{_datarootdir}/%{name}
%dir %{_datarootdir}/%{name}/styles

%changelog
* Sat Feb 11 2023 jkowalczyk@suse.com
- Update to version 2.23.0:
  * fix: create `lintTxt`
  * chore: update go.mod
  * feat: add `--filter`
  * feat: Add pre-commit support (#558)
  * chore: update runner name
  * Add `perf` workflow
  * docs: fix typos (#553)
  * chore: set version for Docker
* Wed Jan 18 2023 jkowalczyk@suse.com
- Update to version 2.22.0:
  * chore: disable choco step for now
  * chore: add `ldflags`
  * chore: add `goos` section
  * chore: specify `choco` version
  * chore: install `choco`
  * chore: fix docker version
  * Add choco section to GoReleaser
  * Remove `atom` files
  * refactor: remove outdated `HasUpdate` check
  * Allow for more generic errors in loadPkg (#543)
  * Fix dic count
  * fix: add `SM` to metric
  * docs: update year
  * chore: fix excutable name
  * feat: install package from local directory (#534)
  * chore: use `docker buildx`
* Wed Dec 14 2022 jkowalczyk@suse.com
- Update to version 2.21.3:
  * refactor: remove debug message
  * fix: always use last `StylesPath` loaded
  * feat(config): expand ~ to home directory (#530)
  * refactor: remove `ioutil`
  * fix: don't treat `span` as a block
* Thu Nov 24 2022 jkowalczyk@suse.com
- Update to version 2.21.2:
  * fix: allow `.vale` in `StylesPath`
  * fix: allow `.vale` in `StylesPath`
  * refactor: add note about `os` module
  * feat: enable access to `os` module in `script`
* Thu Nov 24 2022 jkowalczyk@suse.com
- Update to version 2.21.1:
  * test: re-enable Non-Existent case
  * refactor: remove `StylesPath` from example config
  * fix: remove override logic from `loadConfig`
  * feat: support using local and system dics
  * docs: comment typo
  * fix: correctly resolve `dicpath`
  * Add CodeQL workflow
  * feat: enable Goldmark's footnote extension
  * chore: ignore `.fleet`
  * refactor: align structs
  * fix: report exact Asciidoctor error
* Fri Oct 28 2022 jkowalczyk@suse.com
- Update to version 2.21.0:
  * test: add another case for `IgnoredClasses`
  * refactor: report actual XML error message
  * test: add table test case for `IgnoredClasses`
  * docs: update `.vale.ini` config
  * docs: update `.vale.ini` config
  * docs: update `.vale.ini` config
  * feat: support comments in ignore files
  * feat: ignore blocks by class
  * fix: handle `0` suffix
  * fix: `skip` should be an upper bound
  * fix: `skip` should be an upper bound
  * fix: ensure sequence length is non-zero
  * feat: load local packages
  * chore: restore Dockerfile
  * chore: restore Dockerfile
* Wed Oct 12 2022 Jeff Kowalczyk <jkowalczyk@suse.com>
- Add empty directory /usr/share/vale/styles for use by other
  packages to install vale styles. Use a shortname directory per
  style package, e.g. /usr/share/vale/styles/suse
* Wed Sep 14 2022 jkowalczyk@suse.com
- Update to version 2.20.2:
  * chore: fix main package
  * chore: fix Go version for GoReleaser
  * refactor: remove old doc.go
  * refactor: remove old doc.go
  * Consistent color reporting
  * refactor: remove unused error
  * refactor: remove `internal/cli`
  * refactor: remove `internal/cli`
  * fix: support numbers in Vocab entries
* Sun Jul 24 2022 jkowalczyk@suse.com
- Update to version 2.20.1:
  * refactor: fix `IsPhrase` tests
  * test: add tests for `IsPhrase`
  * refactor: add missing `doc.go`
  * fix: set action params
  * fix: improve error message
  * fix: check all error conditions
  * Fix: Enable PIE mode
  * Fix: Remove exec bit from docs
  * docs: add Org support
* Tue Jul  5 2022 jkowalczyk@suse.com
- Update to version 2.20.0:
  * chore: add workflow to bump pkgs
  * fix: check `head` indexes before removing
  * feat: support ignore patterns in Org
  * chore: bump Go version
  * test: add another Org case
  * feat: add support for Org files
* Fri Jul  1 2022 jkowalczyk@suse.com
- Initial package version 2.19.0:
  * chore: add dispatch step
  * refactor: remove unused param
  * feat: support tag matching for sequence anchor
  * chore: build linux_arm64
  * chore: move fixtures to testdata
  * chore: move pkg managers to their own repo
  * chore: add chocolatey files
  * feat: more patterns
  * refactor: remove manual offset
  * fix: use line index as comment offset
  * chore: mark fixtures as vendored
  * chore: remove lgtm.yml
  * chore: mark `testdata` as vendored
  * feat: support embedded markup
  * docs: update link
